=== modified file 'doc/centralized_workflow.txt'
--- doc/centralized_workflow.txt	2006-10-31 20:40:59 +0000
+++ doc/centralized_workflow.txt	2007-02-27 21:24:38 +0000
@@ -13,7 +13,7 @@
 manner. Bazaar_ is designed to be very flexible and allows several
 different workflows, from fully decentralized to mostly centralized.  The
 workflow used here is meant to ease a new user into more advanced usage of
-Bazaar_, and allows them to work in a mix of centralized and decentralized
+Bazaar_, and allow them to work in a mix of centralized and decentralized
 operations.
 
 In general, this document is meant for users coming from a background of
@@ -87,16 +87,19 @@
   % bzr init-repo --no-trees sftp://centralhost/srv/bzr/
 
 You can think of this step as similar to setting up a new cvsroot, or
-subversion repository.
-
-
-Versioning an existing project
-==============================
+subversion repository.  The {{{--no-trees}}} option tells bzr to not
+populate the directory with a working tree.  This is appropriate since
+no one will be making changes directly in the branches within the
+central repository.
+
+
+Placing an existing project into Bazaar
+=======================================
 
 Now that we have a repository, let's create a versioned project. Most of
 the time, you will already have some code that you are working with,
 that you now want to version using Bazaar_. If the code was originally
-in source control, there are many ways to convert the project to Bazaar_
+in source control there are many ways to convert the project to Bazaar_
 without losing any history. However, this is outside the scope of this
 document. See `Tracking Upstream`_ for some possibilities (section
 "Converting and keeping history").
@@ -112,8 +115,8 @@
 ----------------------------------------
 
 So first, we want to create a branch in our remote Repository, where we
-will want to host the project.  Let's assume we have a project named
-"sigil" that we want to start versioning.
+want to host the project.  Let's assume we have a project named
+"sigil" that we want to put under version control.
 
 ::
 
@@ -141,7 +144,7 @@
   % bzr commit -m "Initial import of Sigil"
 
 
-In the example above, we created an empty branch (the ``/sigil`` branch)
+In the previous section, we created an empty branch (the ``/sigil`` branch)
 on ``centralhost``, and then checkout out this empty branch onto our
 workstation to add files from our existing project.
 There are many ways to setup your working directory, but the steps above
@@ -170,7 +173,7 @@
 the checkouts will be out of date with the current version.
 At commit time, Bazaar_ will inform the user of this and prevent them from
 committing. To get up to date, use ``bzr update`` to update the
-tree with the remote changes. This may require resolving conflicts, if the
+tree with the remote changes. This may require resolving conflicts if the
 same files have been modified.
 
 
@@ -211,12 +214,12 @@
 not interrupt people who are working on other parts of the code.  Because
 we have a checkout, any commits made in the ``~/work/sigil/doodle-fixes/``
 will also show up on ``centralhost``. [#nestedbranches]_ It is also
-possible to have 2 developers collaborate on one of these branches, just
+possible to have two developers collaborate on one of these branches, just
 like they would have collaborated on the ``dev`` branch. [#cbranch]_
 
 .. [#nestedbranches] It may look odd to have a branch in a subdirectory of
    another branch. This is just fine, and you can think of it as a
-   heirarchial namespace. Where the nested branch is derived from the
+   hierarchical namespace where the nested branch is derived from the
    outer branch.
 
 .. [#cbranch] When using lots of independent branches, having to retype
@@ -226,7 +229,11 @@
    Which is designed to take a base branch, create a new public branch,
    and create a checkout of that branch, all with much less typing.
    Configuring ``cbranch`` is outside the scope of this document, but the
-   final commands look like ``bzr cbranch dev my-feature-branch``
+   final commands are similar to:
+
+::
+
+   % bzr cbranch dev my-feature-branch
 
 .. _bzrtools: https://launchpad.net/products/bzrtools
 
@@ -275,7 +282,8 @@
                sftp://centralhost/srv/bzr/sigil/user-b
 
 This gives each developer their own branch to work on. And, they can
-easily create a new feature branch for themselves with just[#cbranch]_::
+easily create a new feature branch for themselves with just [#cbranch]_
+::
 
   % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
                sftp://centralhost/srv/bzr/sigil/user-a/feature 
@@ -289,20 +297,20 @@
 Shared Repository
 -----------------
 
-Bazaar_ has the concept of a "Shared Repository". This is similar to the
-concept of other RCS's repository. Such as in Subversion, where you have a
-remote repository, which is where all of the history is stored, and
-locally you don't have any history information, only a checkout of the
-working tree files. Note that "Shared" in this context means shared
-between branches. It *may* be shared between people, but standalone
-branches can also be shared between people.
+Bazaar_ has the concept of a "Shared Repository". This is similar to
+the concept of a repository in other RCSs. For example, in Subversion
+you have a remote repository, which is where all of the history is
+stored, and locally you don't have any history information, only a
+checkout of the working tree files. Note that "Shared" in this context
+means shared between branches. It *may* be shared between people, but
+standalone branches can also be shared between people.
 
 In Bazaar_ terms, a "Shared Repository" is a location where multiple
-branches can **share** their revision history information. Because Bazaar_
-wants to support decentralized workflows, it is possible for every branch
-to maintain its own revision history information. But this is often
-inefficient, since related branches share history, and they might as well
-share the storage as well.
+branches can **share** their revision history information. In order to
+support decentralized workflows, it is possible for every branch to
+maintain its own revision history information. But this is often
+inefficient, since related branches share history, and they might as
+well share the storage as well.
 
 
 .. 

=== modified file 'doc/configuration.txt'
--- doc/configuration.txt	2007-02-13 22:34:57 +0000
+++ doc/configuration.txt	2007-02-27 21:24:38 +0000
@@ -6,10 +6,10 @@
 
 Location of configuration file
 ==============================
-Each user gets a pair of configurations files in $HOME/.bazaar. The first
-one, named bazaar.conf, includes default configuration options. The other
-file, locations.conf, contains configuration information for specific
-branch locations.
+Each user gets a pair of configurations files in ``$HOME/.bazaar``. The first
+one, named ``bazaar.conf``, includes default configuration options. The other
+file, ``locations.conf``, contains configuration information for specific
+branch locations.  These files are sometimes referred to as ``ini files``.
 
 General Format
 ==============
@@ -25,15 +25,15 @@
 Section Headers
 ---------------
 A section header is a word enclosed in brackets that starts at the begining
-of a line, typical section headers look like this::
+of a line.  A typical section headers look like this::
 
     [DEFAULT]
 
 The only valid section header for bazaar.conf is [DEFAULT], which is case
-senstive. The default section provides for setting variables which can be
+sensitive. The default section provides for setting variables which can be
 overridden with the branch config file.
 
-For locations.conf, the variables from the section with the longest matching
+For ``locations.conf``, the variables from the section with the longest matching
 section header are used to the exclusion of other potentially valid section
 headers. A section header uses the path for the branch as the section
 header. Some examples include::
@@ -47,8 +47,7 @@
 -----------------
 
 A section variable resides within a section. A section variable contains a
-variable name, an equals sign and a value and generally takes the following
-form::
+variable name, an equals sign and a value.  For example::
 
     email            = John Doe <jdoe@isp.com>
     check_signatures = require
@@ -87,12 +86,12 @@
 The main configuration file, bazaar.conf
 ----------------------------------------
 
-The main configuration file, $HOME/.bazaar/bazaar.conf, only allows one
-section called '''[DEFAULT]'''. This default section contains the default
+The main configuration file, ``$HOME/.bazaar/bazaar.conf``, only allows one
+section called ``[DEFAULT]``. This default section contains the default
 configuration options for all branches. The default section can be
-overriden by providing a branch specific section in locations.conf.
+overriden by providing a branch specific section in ``locations.conf``.
 
-A typical bazaar.conf section often looks like the following::
+A typical ``bazaar.conf`` section often looks like the following::
 
     [DEFAULT]
     email             = John Doe <jdoe@isp.com>
@@ -100,11 +99,11 @@
     check_signatures  = check-available
     create_signatures = when-required
 
-$HOME/.bazaar/locations.conf allows one to specify overriding settings for a
+``$HOME/.bazaar/locations.conf`` allows one to specify overriding settings for a
 specific branch. The format is almost identical to the default section in
 bazaar.conf with one significant change: The section header, instead of
 saying default, will be the path to a branch that you wish to override a
-value for. The ? and * wildcards are supported::
+value for. The '?' and '*' wildcards are supported::
 
     [/home/jdoe/branches/nethack]
     email = Nethack Admin <nethack@nethack.com>
@@ -116,7 +115,7 @@
     [http://bazaar-vcs.org/bzr/*]
     check_signatures  = require
 
-Common Variable options
+Common Variable Options
 =======================
 
 email
@@ -130,14 +129,14 @@
 ------
 The path of the editor that you wish to use if *bzr commit* is run without
 a commit log message. This setting is trumped by the environment variable
-$BZR_EDITOR, and overrides $VISUAL and $EDITOR.
+``$BZR_EDITOR``, and overrides ``$VISUAL`` and ``$EDITOR``.
 
 check_signatures
 ----------------
 Defines the behavior for signatures.
 
 require
-    the gnupg signature for revisions must be present and must be valid
+    The gnupg signature for revisions must be present and must be valid.
 
 ignore
     Do not check gnupg signatures of revisions. 
@@ -145,39 +144,38 @@
 check-available
     (default) If gnupg signatures for revisions are present, check them.
     Bazaar will fail if it finds a bad signature, but will not fail if
-    no signature is present
+    no signature is present.
 
 create_signatures
 -----------------
-Defines the behaviour of signing revisions. Has three possible values:
-always, never and when-requied.
+Defines the behaviour of signing revisions.
 
 always
-    sign every new revision that is committed
+    Sign every new revision that is committed.
 
 when-required
     (default) Sign newly committed revisions only when the branch requires
-    signed revisions
+    signed revisions.
 
 never
-    Refuse to sign newly committed revisions, even if the branch requires signatures
+    Refuse to sign newly committed revisions, even if the branch requires signatures.
 
 recurse
 -------
-Only useful in locations.conf. Defines whether or not the configuration for
+Only useful in ``locations.conf``. Defines whether or not the configuration for
 this section applies to subdirectories:
 
 true
-    (default) This section applies to subdirectories as well
+    (default) This section applies to subdirectories.
 
 false
     This section only applies to the branch at this directory and not
-    branches 
+    branches below it. 
 
 gpg_signing_command
 -------------------
 (Default: "gpg"). Which program should be used to sign and check revisions.
-example::
+For example::
 
     gpg_signing_command = /usr/bin/gnpg
 
@@ -186,34 +184,33 @@
 ================
 
 These options apply only to branches that use the "experimental-branch6"
-format.  They are usually set in .bzr/branch/branch.conf automatically, but
-may be manually set in locations.conf or bazaar.conf
+format.  They are usually set in ``.bzr/branch/branch.conf`` automatically, but
+may be manually set in ``locations.conf`` or ``bazaar.conf``.
 
 append_revisions_only
 ---------------------
-If set to "True", then revisions can only be appended to the log, not removed.
-A branch with this setting enabled can only pull from another branch if the
-other branch's log is a longer version of its own.
-
-This is normally set by ``bzr init --append-revisions-only``.
+If set to "true" then revisions can only be appended to the log, not
+removed.  A branch with this setting enabled can only pull from
+another branch if the other branch's log is a longer version of its
+own.  This is normally set by ``bzr init --append-revisions-only``.
 
 parent_location
 ---------------
 If present, the location of the default branch for pull or merge.
-
-This is normally set by ``pull --remember`` or ``merge --remember``
+This option is normally set by ``pull --remember`` or ``merge
+--remember``
 
 push_location
 -------------
-If present, the location of the default branch for push.  This is normally
-set by ``push --remember``.
+If present, the location of the default branch for push.  This option
+is normally set by ``push --remember``.
 
 bound_location
 --------------
-The location that commits should go to when acting as a checkout.  (Normally
-set by ``bind``)
+The location that commits should go to when acting as a checkout.
+This option is normally set by ``bind``.
 
 bound
 -----
 If set to "True", the branch should act as a checkout, and push each commit to
-the bound_location.  (Normally set by ``bind``/``unbind``.)
+the bound_location.  This option is normally set by ``bind``/``unbind``.

=== modified file 'doc/plugins.txt'
--- doc/plugins.txt	2006-07-30 06:52:39 +0000
+++ doc/plugins.txt	2007-02-27 21:24:38 +0000
@@ -7,17 +7,18 @@
 What is a Plugin
 ================
 A plugin is an external component for Bazaar that is typically made by
-third parties. A plugin is capable of augmenting Bazaar by adding or
-replacing new or current functionality in Bazaar. Plugins often work as
-a way for developers to test new features for Bazaar prior to inclusion
-in the official codebase. Plugins can do a variety of things, including
+third parties. A plugin is capable of augmenting Bazaar by adding new
+functionality.  A plugin can also change current Bazaar behavior by
+replacing current functionality. Plugins often work as a way for
+developers to test new features for Bazaar prior to inclusion in the
+official codebase. Plugins can do a variety of things, including
 overriding commands, adding new commands, providing additional network
-transports, customizing log output. The sky is the limit for the
-customization that can be done through plugins.
+transports, or customizing log output. The sky is the limit for the
+customizations that can be done through plugins.
 
 Where to find Plugins 
 =====================
-We keep our list of plugins on the http://bazaar-vcs.org/PluginRegistry page.
+We keep our list of plugins on the http://bazaar-vcs.org/BzrPlugins page.
 
 Writing a plugin
 ================
@@ -26,22 +27,22 @@
 but most plugins supply new commands.
 
 To create a command, make a new object that derives from
-`bzrlib.commands.Command`, and name it cmd_foo, where foo is the name of
+``bzrlib.commands.Command``, and name it ``cmd_foo``, where foo is the name of
 your command.  If you create a command whose name contains an underscore,
 it will appear in the UI with the underscore turned into a hyphen.  For
-example, "cmd_baz_import" will appear as "baz-import".  For examples of how
-to write commands, please see builtins.py.
+example, `cmd_baz_import` will appear as `baz-import`.  For examples of how
+to write commands, please see ``builtins.py``.
 
 Once you've created a command you must register the command with
-`bzrlib.commands.register_command(cmd_foo)`.  You must register the command
-when your file is imported, otherwise bzr will not see it.
+``bzrlib.commands.register_command(cmd_foo)``.  You must register the
+command when your file is imported, otherwise bzr will not see it.
 
-Bzr will scan **bzrlib/plugins** and **~/.bazaar/plugins** for plugins by
-default.  You can override this with **BZR_PLUGIN_PATH**.  Plugins may be
-either modules or packages.  If your plugin is a single file, you can
-structure it as a module.  If it has multiple files, or if you want to
-distribute it as a bzr branch, you should structure it as a package, i.e. a
-directory with an **__init__.py** file.
+Bzr will scan ``bzrlib/plugins`` and ``~/.bazaar/plugins`` for plugins
+by default.  You can override this with ``BZR_PLUGIN_PATH``.  Plugins
+may be either modules or packages.  If your plugin is a single file,
+you can structure it as a module.  If it has multiple files, or if you
+want to distribute it as a bzr branch, you should structure it as a
+package, i.e. a directory with an ``__init__.py`` file.
 
 Please feel free to contribute your plugin to BzrTools, if you think it
 would be useful to other people.
@@ -49,18 +50,18 @@
 How to Install a plugin 
 =======================
 Installing a plugin is very easy! One can either install a plugin
-systemwide or on a user by user basis. Both methods involve create a
-"plugins" directory. Within this directory one can place plugins in
-subdirectories. For example, "plugins/bzrtools/".
+system-wide or on a per user basis. Both methods involve creating a
+``plugins`` directory. Within this directory one can place plugins in
+subdirectories. For example, ``plugins/bzrtools/``.
 
-Two locations are currently checked; the bzrlib/plugins directory
-(typically found in /usr/lib/python2.4/site-packages/bzrlib/plugins/) and
-$HOME/.bazaar/plugins/.
+Two locations are currently checked:  the bzrlib/plugins directory
+(typically found in ``/usr/lib/python2.4/site-packages/bzrlib/plugins/``) and
+``$HOME/.bazaar/plugins/``.
 
 One can additionally override the home plugins by setting the environment
-variable BZR_PLUGIN_PATH to a directory that contains plugins. The
-installation of a plugin can be checked by running **bzr plugins** at
-any time. New commands can be seen by running **bzr help commands**.
+variable ``BZR_PLUGIN_PATH`` to a directory that contains plugins. The
+installation of a plugin can be checked by running ``bzr plugins`` at
+any time. New commands can be seen by running ``bzr help commands``.
 
 Plugins work particularly well with Bazaar branches. For example, to
 install the bzrtools plugins for your main user account, one can perform

=== modified file 'doc/server.txt'
--- doc/server.txt	2006-09-18 09:58:40 +0000
+++ doc/server.txt	2007-02-27 21:24:38 +0000
@@ -28,12 +28,12 @@
 protocol as a dumb server.  This is the first stage high performance server
 functionality to be delivered.
 
-The current high performance server provides read only access by default for
-security. To enable read-write access, run it with --allow-writes. When using
-the SSH access method, bzr automatically runs with with the --allow-writes
-option.
+The current high performance server provides read-only access by
+default for security. To enable read-write access, run it with
+``--allow-writes``. When using the SSH access method, bzr
+automatically runs with with the ``--allow-writes`` option.
 
-It can be configured to run in three different ways:
+The server can be configured to run in three different ways:
 
 SSH
 ---
@@ -42,26 +42,27 @@
 
     BZR_REMOTE_PATH=~/bin/bzr bzr log bzr+ssh://host/path/to/branch
 
-The `BZR_REMOTE_PATH` environment variable adjusts how `bzr` will be invoked on
+The ``BZR_REMOTE_PATH`` environment variable adjusts how `bzr` will be invoked on
 the remote system.  By default, just `bzr` will be invoked, which requires the
 `bzr` executable to be on the default search path.
 
-The `bzr+ssh://` URL scheme only supports absolute paths from the root of the
-filesystem.  Future versions are expected to support `~` in the same way as
-`sftp://` URLs.
+The ``bzr+ssh://`` URL scheme only supports absolute paths from the root of the
+filesystem.  Future versions are expected to support ``~`` in the same way as
+``sftp://`` URLs.
 
 inetd
 -----
 
-This example shows how to run `bzr` with a dedicated user `bzruser` for a shared
-repository in `/srv/bzr/repo` which has a branch at `/srv/bzr/repo/branchname`
+This example shows how to run `bzr` with a dedicated user `bzruser`
+for a shared repository in ``/srv/bzr/repo`` which has a branch at
+``/srv/bzr/repo/branchname``.
 
 Running a Bazaar server from inetd requires an inetd.conf entry::
 
     1234  stream  tcp  nowait  bzruser  /usr/bin/bzr serve --inet --directory=/srv/bzr/repo
 
 When running client commands, the URL you supply is a `bzr://` URL relative to
-the `--directory` option given in inetd.conf::
+the ``--directory`` option given in inetd.conf::
 
     bzr log bzr://host:1234/branchname
 
@@ -69,8 +70,8 @@
 ---------
 
 This mode has the same path and URL behaviour as the inetd mode.  To run as a
-specific, you should use `su` or login as that user.  This example runs bzr
-serve on `localhost` port `1234`.
+specific user, you should use ``su`` or login as that user.  This example runs ``bzr
+serve`` on `localhost` port `1234`.
 
 server::
 

=== modified file 'doc/setting_up_email.txt'
--- doc/setting_up_email.txt	2006-07-30 06:52:39 +0000
+++ doc/setting_up_email.txt	2007-02-27 21:24:38 +0000
@@ -2,38 +2,40 @@
 Setting up email
 ================
 
-The various ways that exist to tell Bazaar your email address for
+Description of the various ways to specify to Bazaar your email address for
 commits.
 
 Why set up an email address with Bazaar?
 ========================================
-Bazaar stores the claimed email address in revisions when they're
-created, so that people can tell who commited which revisions.  Of course,
-people can change the email address claimed, so you have to trust the
-people involved.  Additionally, the email address in a revision gives
-others a way to contact the author of a revision for credit and/or blame.
-:)
+Bazaar stores the specified email address in revisions when they're
+created so that people can tell who commited which revisions.  The
+email addresses are not verified, therefore they could be bogus, so
+you have to trust the people involved in your project.  Additionally,
+the email address in a revision gives others a way to contact the
+author of a revision for credit and/or blame.  :)
 
 How to setup your email address 
 ===============================
 Bazaar will try to guess an email address based on your username and the
 hostname if none is set.  This will probably not be what you want, so three
-ways exist to tell Bazaar what email to use
+ways exist to tell Bazaar what email to use:
 
- * You can set your email in the default ini file,
+ * You can set your email in the default configuration file,
  * You can set emails per-branch in the branch specific ini file,
  * Or your email can be set by an environmental variable.
 
 The order of precedence is
 
- 1. If the `$BZREMAIL` env variable is set, use it.
- 2. If an email is set for your current branch in the `locations.conf` ini
+ 1. If the ``$BZR_EMAIL`` environment variable is set.
+ #. If an email is set for your current branch in the ``locations.conf``
     file.
- 3. If an email is set in the `bazaar.conf` default ini file.
- 4. If the `$EMAIL` env variable is set.
- 5. Bazaar will try to guess based on your username and the hostname.
+ #. If an email is set four your current branch in the
+    ``.bzr/branch/branch.conf`` file.
+ #. If an email is set in the ``bazaar.conf`` default configuration file.
+ #. If the `$EMAIL` environment variable is set.
+ #. Bazaar will try to guess based on your username and the hostname.
 
-To check on what Bazaar thinks your current email is, use the '''whoami'''
+To check on what Bazaar thinks your current email is, use the ``whoami``
 ("who am i?") command::
 
     % bzr whoami
@@ -49,14 +51,14 @@
 
     % bzr whoami --branch 'Joe Cool <joe@example.com>'
 
-These modify your global bazaar.conf or branch branch.conf file, respectively.
+These modify your global ``bazaar.conf`` or branch ``branch.conf`` file, respectively.
 
-Setting email via default ini file
-==================================
-To use the default ini file, create the file `$HOME/.bazaar/bazaar.conf` (on
-Windows this is `%APPDATA%\bazaar\2.0\bazaar.conf`) and set an email address
+Setting email via default configuration file
+============================================
+To use the default ini file, create the file ``$HOME/.bazaar/bazaar.conf`` (on
+Windows this is ``%APPDATA%\bazaar\2.0\bazaar.conf``) and set an email address
 as shown below.  Please note that the word DEFAULT is case sensitive, and
-must be in upper-case.::
+must be in upper-case. ::
 
     [DEFAULT]
     email=Your Name <name@isp.com>
@@ -68,28 +70,27 @@
 ===================================
 
 The second approach is to set email on a branch by branch basis by using the
-`$HOME/.bazaar/locations.conf` ini file, thusly::
+``$HOME/.bazaar/locations.conf`` ini file, thusly::
 
     [/some/branch/location]
     email=Your Name <name@other-isp.com>
 
-This will set your email address in the branch at `/some/branch/location`,
-overriding the default specified in the `bazaar.conf` above.
+This will set your email address in the branch at ``/some/branch/location``,
+overriding the default specified in the ``bazaar.conf`` above.
 
-Setting email via environment
------------------------------
-The final method Bazaar will use is checking for the `$BZREMAIL` and
-`$EMAIL` environment variables.  Generally, one would use this method to
+Setting email via environment variable
+--------------------------------------
+The final method Bazaar will use is checking for the ``$BZR_EMAIL`` and
+``$EMAIL`` environment variables.  Generally, one would use this method to
 override the email in a script context.  If you would like to set a general
 default, then please see the ini methods above.
 
-
 Concerns for spam
 =================
 Some people want to avoid sharing their email address so as not to get
 spam.  Bazaar will never disclose your email address, unless you publish
 a branch or changeset in a public location.  It's recommended that you
-''do'' use a real address, so that people can contact you about your work,
+*do* use a real address, so that people can contact you about your work,
 but it's not required.  You can use an address which is obfuscated, which
 bounces, or which goes through an anti-spam service such as
 `spamgourmet.com`.

=== modified file 'doc/specifying_revisions.txt'
--- doc/specifying_revisions.txt	2006-10-11 22:43:03 +0000
+++ doc/specifying_revisions.txt	2007-02-27 21:24:38 +0000
@@ -3,15 +3,15 @@
 =============================
 
 Description of the subarguments for ``-r`` as used by commands such as
-**bzr log** and **bzr merge**.
+``bzr log`` and ``bzr merge``.
 
 You can get the online documentation with ``bzr help revisionspec``.
 
 Revision specs and ranges
 =========================
 
-**bzr** has a very expressive way to specify a revision, or a range of revisions.
-We'll take the example of the **log** command.
+``bzr`` has a very expressive way to specify a revision, or a range of revisions.
+We'll take the example of the ``log`` command.
 
 To specify a range of revisions, use for example::
 
@@ -22,10 +22,10 @@
     $ bzr log -r 1..
     $ bzr log -r ..4
 
-Note::
+Note:
     Omitting the lower bound doesn't work on currently released versions.
 
-Other commands, like **bzr cat** take only one revision, not a range, like::
+Other commands, like ``bzr cat`` take only one revision, not a range, like::
 
     $ bzr cat -r 42 foo.c
 
@@ -58,7 +58,7 @@
 -------
 
 Positive numbers denote revision numbers in the current branch. Revision
-numbers are labelled as "revno" in the output of **bzr log**.  To display
+numbers are labelled as "revno" in the output of ``bzr log``.  To display
 the log for the first ten revisions::
 
     $ bzr log -r ..10
@@ -82,8 +82,8 @@
 revid
 -----
 
-**revid** allows specifying a an internal revision ID, as show by **bzr
-testament** and some other commands.
+**revid** allows specifying a an internal revision ID, as show by ``bzr
+testament`` and some other commands.
 
 For example::
 
@@ -98,7 +98,7 @@
     that appears before ''rev'' in the revision history, or the revision that
     was current when ''rev'' what comitted.
 
-''rev'' can be any revision specifier.
+''rev'' can be any revision specifier and may be chained.
 
 For example::
 
@@ -131,14 +131,14 @@
 --------
 
 **ancestor**:*path*
-    specifies the common ancestor between the current branch,and a 
+    specifies the common ancestor between the current branch and a 
     different branch. This is the same ancestor that would be used for
     merging purposes.
 
 *path* may be the URL of a remote branch, or the file path to a local branch.
 
 For example, to see what changes were made on a branch since it was forked
-off **../parent**::
+off ``../parent``::
 
     $ bzr diff -r ancestor:../parent
 
@@ -146,9 +146,9 @@
 ------
 
 branch
-   ''path'' specifies the latest revision in another branch.
+   ``path`` specifies the latest revision in another branch.
 
-''path'' may be the URL of a remote branch, or the file path to a local branch.
+``path`` may be the URL of a remote branch, or the file path to a local branch.
 
 For example, to get the differences between this and another branch::
 

=== modified file 'doc/using_aliases.txt'
--- doc/using_aliases.txt	2006-07-30 06:52:39 +0000
+++ doc/using_aliases.txt	2007-02-27 21:24:38 +0000
@@ -6,8 +6,8 @@
 are an easy way to create shortcuts for commonly-typed commands, or to set
 defaults for commands.
 
-Command aliases can be defined in the **[ALIASES]** section of your
-**.bazaar/bazaar.conf** file. Aliases start with the alias name, then an
+Command aliases can be defined in the ``[ALIASES]`` section of your
+``.bazaar/bazaar.conf`` file. Aliases start with the alias name, then an
 equal sign, then a command fragment.  Here's an example ALIASES section:
 
 Examples
@@ -23,29 +23,35 @@
 Explanation of examples
 =======================
 
- * The first alias makes a new 'recentlog' command that shows the logs for the
+ * The first alias makes a new ``recentlog`` command that shows the logs for the
    last three revisions
- * The **ll** alias shows the last 10 log entries in line format.
- * the **commit** alias sets the default for commit to refuse to commit if new
+ * The ``ll`` alias shows the last 10 log entries in line format.
+ * the ``commit`` alias sets the default for commit to refuse to commit if new
    files in the tree are not recognized.
- * the **diff** alias adds the coveted -p option to diff
-
+ * the ``diff`` alias adds the coveted -p option to diff
+
+Using the Aliases
+=================
+The aliases defined above would be used like so: ::
+
+   % bzr recentlog
+   % bzr ll
+   % bzr commit
+   % bzr diff
 
 Rules for Aliases
 =================
 
  * You can override parts of the options given in an alias by overriding it.
-   For example, if you run **lastlog -r-5..**, you will only get five
+   For example, if you run ``lastlog -r-5..``, you will only get five
    line-based log entries instead of 10.
  * Aliases can override the standard behaviour of existing commands by giving
-   an alias name that is thesame as the orignal command. For example, default
-   commit is changed with **commit=commit --strict**.
- * Aliases can not refer to other aliases. In other words making a
-   **lastlog** alias and referring to it with a **ll** alias will not work.
-
-This includes aliases that override standard commands
-
- * Giving the **--no-aliases** to the bzr command will tell it to ignore aliases
-   for that run. For example, running **bzr --no-aliases commit** will perform a
-   standard commit instead not do a **commit --strict**.
+   an alias name that is the same as the orignal command. For example, default
+   commit is changed with ``commit=commit --strict``.
+ * Aliases cannot refer to other aliases. In other words making a
+   ``lastlog`` alias and referring to it with a ``ll`` alias will not work.
+   This includes aliases that override standard commands
+ * Giving the ``--no-aliases`` to the bzr command will tell it to ignore aliases
+   for that run. For example, running ``bzr --no-aliases commit`` will perform a
+   standard commit instead not do a ``commit --strict``.
 

